;; Pinaret - Static website generator
;; Copyright (C) 2016  Josep Portella Florit <hello@josep-portella.com>
;;
;; This program is free software: you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation, either version 3 of the License, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program.  If not, see <http://www.gnu.org/licenses/>.

#lang racket

(require "provide.rkt" "runtime.rkt" "base.rkt" "system.rkt"
         racket/cmdline setup/getinfo)

(define/provide customization-file "custom.rkt")

(define-syntax/provide command-line/defaults
  (syntax-rules ()
    [(_ exp ...)
     (let ([program (path-replace-suffix
                     (file-name-from-path (find-system-path 'run-file))
                     "")])
       (with-handlers
           ([exn:fail?
             (lambda _
               (printf "Try '~a --help' for usage information.~%" program)
               (exit))])
         (command-line
          #:program program
          #:once-each [("--version" "-v") "Show version"
                       (printf "~a ~a~%" program
                               ((get-info '("pinaret")) 'version))
                       (exit)]
          #:once-any exp ...)))]))

(define-syntax/provide main/defaults
  (syntax-rules ()
    [(_ exp ...)
     (with-handlers ([exn:break? (λ (e) (exit 1))])
       (current-procedures (list base-procedures
                                 system-procedures))
       (current-cache (make-cache))
       (when (file-exists? customization-file)
         (dynamic-require customization-file #f))
       exp ...)]))
